@@ -19,13 +19,14 @@ written to use `self.stdout.write()`,
 
 - Catherine Devlin, Jan 03 2008 - catherinedevlin.blogspot.com
 
+mercurial repository at http://www.assembla.com/wiki/show/python-cmd2
 CHANGES:
 As of 0.3.0, options should be specified as `optparse` options.  See README.txt.
 flagReader.py options are still supported for backward compatibility
 """
 import cmd, re, os, sys, optparse, subprocess, tempfile, pyparsing, doctest, unittest
 from optparse import make_option
-__version__ = '0.4.1'
+__version__ = '0.4.2'
 
 class OptionParser(optparse.OptionParser):
     def exit(self, status=0, msg=None):
@@ -329,7 +330,11 @@ class Cmd(cmd.Cmd):
                 self.stdout = tempfile.TemporaryFile()
                 if statement.output == '>>':
                     self.stdout.write(getPasteBuffer())
-        stop = cmd.Cmd.onecmd(self, statement.statement)
+        try:
+            stop = cmd.Cmd.onecmd(self, statement.statement)
+        except Exception, e:
+            print str(e)
+            return False
         try:
             if statement.command not in self.excludeFromHistory:
                 self.history.append(statement.fullStatement)
@@ -774,6 +779,7 @@ class Cmd2TestCase(unittest.TestCase):
             line = line.rstrip()
             if line.startswith(bareprompt):
                 line = line.replace(bareprompt, '', 1)
+            lines.append(line)
         return '\n'.join(lines).strip()
     def tearDown(self):
         if self.CmdApp:
